..
   Copyright (C) 2015-2022 CERN.
   Invenio is free software; you can redistribute it and/or modify it
   under the terms of the MIT License; see LICENSE file for more details.


.. include:: ../AUTHORS.rst
